@@ -1,9 +1,8 @@
 use ipify_rs::*;
 use log::info;
 
-fn doit(e: Engine) {
+fn doit() {
     let ip = Ipify::new();
-    ip.with(e);
 
     println!("IP4={:?}", ip.set(Op::IPv4).call());
     println!("IP6={:?}", ip.set(Op::IPv6).call());
@@ -20,15 +19,11 @@ fn main() {
     info!("Using default, minimal API");
     println!("IP={}", myip());
 
-    info!("Using defaults (ureq, ipv6)");
+    info!("Using defaults (ipv6)");
     println!("IP={}", Ipify::new().call());
 
     info!("Using defaults, get json");
     println!("IP={}", Ipify::new().set(Op::IPv6J).call());
 
-    info!("Using ureq");
-    doit(Engine::Reqw);
-
-    info!("Using reqwest");
-    doit(Engine::Reqw);
+    doit();
 }
