@@ -8,9 +8,7 @@
 //! ```
 //! use ipify_rs::myip;
 //!
-//! fn main() {
-//!   println!("My IP is: {}", myip());
-//! }
+//! println!("My IP is: {}", myip());
 //! ```
 //!
 //! The full API is described below.
@@ -30,24 +28,13 @@ const ENDPOINT6J: &str = "https://api64.ipify.org?format=json";
 /// ```
 /// use ipify_rs::myip;
 ///
-/// fn main() {
-///     println!("{}", myip())
-/// }
+/// println!("{}", myip())
 /// ```
 ///
 pub fn myip() -> String {
     Ipify::new().call()
 }
 
-/// Describe the available HTTP engines
-#[derive(Clone, Copy, Debug, PartialEq)]
-pub enum Engine {
-    // ureq
-    Ureq,
-    // reqwest
-    Reqw,
-}
-
 /// The current set of operations
 #[derive(Clone, Copy, Debug, PartialEq)]
 pub enum Op {
@@ -64,68 +51,49 @@ pub enum Op {
 /// The main API struct
 #[derive(Clone, Copy, Debug)]
 pub struct Ipify<'a> {
-    /// HTTP Engine
-    pub e: Engine,
     /// Current type of operation
     pub t: Op,
     /// Endpoint, different for every operation
     pub endp: &'a str,
 }
 
+/// Impl. default values.
+impl<'a> Default for Ipify<'a> {
+    fn default() -> Self {
+        Self::new()
+    }
+}
+
 /// API Implementation
 impl<'a> Ipify<'a> {
     /// Create a new API instance client with the defaults
     ///
-    /// Examples:
+    /// Example:
     /// ```
     /// use ipify_rs::*;
     ///
-    /// fn main() {
-    ///   let mut a = Ipify::new();
+    /// let mut a = Ipify::new();
     ///
-    ///   println!("{}", a.call());
-    /// }
+    /// println!("{}", a.call());
     /// ```
     ///
     pub fn new() -> Self {
         Ipify {
-            e: Engine::Ureq,
             t: Op::IPv6,
             endp: ENDPOINT6,
         }
     }
 
-    /// Use the specified HTTP engine
-    ///
-    /// Examples:
-    /// ```
-    /// use ipify_rs::{Ipify, Engine};
-    ///
-    /// fn main() {
-    ///   let mut a = Ipify::new();
-    ///   a.with(Engine::Reqw);
-    ///
-    ///   println!("{}", a.call());
-    /// }
-    /// ```
-    ///
-    pub fn with(mut self, e: Engine) -> Self {
-        self.e = e;
-        self
-    }
-
     /// Specify the subsequent operation to perform on `call()`
     ///
     /// Examples:
     /// ```
     /// use ipify_rs::{Ipify, Op};
     ///
-    /// fn main() {
-    ///   let mut a = Ipify::new();
-    ///   a.set(Op::IPv6J);
+    /// let mut a = Ipify::new();
+    /// a.set(Op::IPv6J);
     ///
-    ///   println!("{}", a.call());
-    /// }
+    /// println!("{}", a.call());
     /// ```
     ///
     pub fn set(mut self, op: Op) -> Self {
@@ -140,22 +108,22 @@ impl<'a> Ipify<'a> {
     }
 
     /// Actually perform the API call
+    ///
+    /// Example:
+    /// ```
+    /// use ipify_rs::Ipify;
+    ///
+    /// let r = Ipify::new().call();
+    ///
+    /// println!("my ip = {}", r);
+    /// ```
+    ///
     pub fn call(self) -> String {
-        match self.e {
-            Engine::Ureq => {
-                let c = ureq::AgentBuilder::new()
-                    .user_agent("ipify-cli/1.0.0")
-                    .build();
-                return c.get(&self.endp).call().unwrap().into_string().unwrap();
-            }
-            Engine::Reqw => {
-                let c = reqwest::blocking::ClientBuilder::new()
-                    .user_agent("ipify-cli/1.0.0")
-                    .build()
-                    .unwrap();
-                return c.get(self.endp).send().unwrap().text().unwrap();
-            }
-        }
+        let c = reqwest::blocking::ClientBuilder::new()
+            .user_agent("ipify-cli/1.0.0")
+            .build()
+            .unwrap();
+        c.get(self.endp).send().unwrap().text().unwrap()
     }
 }
 
@@ -185,10 +153,6 @@ mod tests {
         let c = Ipify::new();
 
         assert_eq!(Op::IPv6, c.t);
-        let c = c.with(Engine::Reqw);
-        assert_eq!(Engine::Reqw, c.e);
-        let c = c.with(Engine::Ureq);
-        assert_eq!(Engine::Ureq, c.e);
     }
 
     #[test]
@@ -196,12 +160,10 @@ mod tests {
         let c = Ipify::new();
 
         assert_eq!(Op::IPv6, c.t);
-        let c = c.with(Engine::Reqw).set(Op::IPv4);
-        assert_eq!(Engine::Reqw, c.e);
+        let c = c.set(Op::IPv4);
         assert_eq!(Op::IPv4, c.t);
 
-        let c = c.set(Op::IPv4J).with(Engine::Ureq);
-        assert_eq!(Engine::Ureq, c.e);
+        let c = c.set(Op::IPv4J);
         assert_eq!(Op::IPv4J, c.t);
     }
 }
